<?php

declare(strict_types=1);

namespace Drupal\social_auth_entra_id\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Session\SessionManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Entra ID login block.
 *
 * @Block(
 *   id = "entra_id_login_block",
 *   admin_label = @Translation("Entra ID Login Block"),
 *   category = @Translation("Login"),
 * )
 */
final class EntraIdLoginBlockBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    // Get the current user.
    $currentUser = \Drupal::currentUser(); // Use the global user service.

    // Check if the user is anonymous.
    if ($currentUser->isAnonymous()) {
      // User is anonymous; provide a login link.
      $route_name = 'social_auth_entra_id.redirect'; // Ensure this matches your routing name.
      $url = \Drupal\Core\Url::fromRoute($route_name);
      $link = Link::fromTextAndUrl($this->t('Log in with Microsoft Entra ID'), $url)->toString();
      $markup = $link;
    } 
    else {
      // User is authenticated; provide a link to their account page.
      $account_url = \Drupal\Core\Url::fromRoute('entity.user.canonical', ['user' => $currentUser->id()]);
      $link = Link::fromTextAndUrl($this->t('Your account'), $account_url)->toString();
      $markup = '';
    }

    return [
      'content' => [
        '#markup' => $markup,
        '#cache' => [
          'max-age' => 0, // Disable caching for dynamic content
        ],
      ],
    ];
  }
}
